pub struct PermutationResult {
pub perm: Vec<usize>,
pub unmatched_source_indices: Vec<usize>,
pub unmatched_target_indices: Vec<usize>,
}Expand description
Output from generating a permutation between two vecs of items. It provides the actual permutation generated as well as information about unmatched items from both the source and target arrays
Fields
perm: Vec<usize>unmatched_source_indices: Vec<usize>unmatched_target_indices: Vec<usize>Trait Implementations
Sourceimpl Debug for PermutationResult
impl Debug for PermutationResult
impl Eq for PermutationResult
Sourceimpl PartialEq for PermutationResult
impl PartialEq for PermutationResult
impl StructuralPartialEq for PermutationResult