pub enum BlockingMode {
External,
Polling,
Precise,
}Expand description
How should we handle syscalls which may block, but are internal to the hermit container? These syscalls are determinizable, but there are multiple methods of doing so. These choices do not apply to blocking syscalls that wait for external conditions outside the container, such as network responses.
Mostly it helps to switch this as: (1) a debugging aid to figure out what is going wrong with a given guest program, or (2) in order to find the more performant mode for a given guest program.
Variants
External
Handle the internal blocking syscall as though it was external, and unblocks at an unpredictable nondeterministic time. These blocked threads will be parked in the scheduler’s BlockedPool.
(TODO: In the future these scheduling decisions will be recorded, and this comment needs to be updated accordingly.)
Polling
Transform each blocking syscall into non-blocking, and then the scheduler will use that non-blocking form to repeatedly poll for completion of the operation. When polling occurs (and the backoff policy there on) is decided by the scheduler. See NOTE [Blocking Syscalls via Internal Polling] in this folder.
Precise
Precisely model the blocking and unblocking behavior inside hermit. TODO: This work is not completed yet for all forms of blocking syscalls.