pub fn log_diff_detailed(
file_a: &Path,
file_b: &Path,
opts: &LogDiffOpts,
) -> LogDiffSummaryExpand description
Like log_diff, but returns the counted comparison evidence rather than a
bare boolean.
pub fn log_diff_detailed(
file_a: &Path,
file_b: &Path,
opts: &LogDiffOpts,
) -> LogDiffSummaryLike log_diff, but returns the counted comparison evidence rather than a
bare boolean.