pub fn record_count(contents: &str) -> usizeExpand description
Total records in a log, including a final record that may still be being
written. Use complete_record_count when the log is still growing.
pub fn record_count(contents: &str) -> usizeTotal records in a log, including a final record that may still be being
written. Use complete_record_count when the log is still growing.