macro_rules! detlog_debug {
(event = $event:expr; $($arg:tt)+) => { ... };
($($arg:tt)+) => { ... };
}Expand description
Macro used to encapsulate tracing should-be-deterministic information. This variant is at a higher log level and requires that logging verbosity is set to DEBUG.