PreemptionReader

Struct PreemptionReader 

pub struct PreemptionReader { /* private fields */ }
A reader for a stream of preemption events.

Implementations

Source

impl PreemptionReader

pub fn new(path: &Path) -> Self

Access the stored PreemptionRecord, and eagerly or lazily load its data from disk.

pub fn into_inner(self) -> PreemptionRecord

Gets the inner PreemptionRecord.

pub fn extract_thread_record(&self, tid: &DetTid) -> Option<ThreadHistory>

Extract a copy of all the entries for a particular thread. Note that this returns None if there is NO record for the thread (not registered). Otherwise, it returns a copy of the ThreadHistory, which may be read into memory or not.

pub fn thread_initial_priority(&self, tid: &DetTid) -> Option<Priority>

Return the initial priority for a thread, if it is recorded in the record.

pub fn all_threads(&self) -> Vec<DetTid> ⓘ

Return all the threads in this record.

pub fn load_all(&self) -> PreemptionRecord

Load the full record of preemptions into memory.

pub fn size(&self) -> usize

Size in number of preemptions, across all threads.