PreemptionRecord

Struct PreemptionRecord 

pub struct PreemptionRecord { /* private fields */ }
A record of all the preemptions and other scheduling events that occur during execution.

Implementations

Source

impl PreemptionRecord

pub fn from_sched_events(events: Vec<SchedEvent>) -> Self

TODO: This is not ideal because PreemptionRecord shouldn’t be doing double duty as an eventlog.

pub fn epoch(&self) -> Option<DateTime<Utc>>

The virtual-time epoch this record was produced under, if it was stored.

pub fn extract_all(&self) -> BTreeMap<DetTid, ThreadHistory>

Make a copy of everything in the PreemptionRecord in a public format.

pub fn as_vecs(&self) -> BTreeMap<DetTid, Vec<(LogicalTime, Priority)>>

Inverse of from_vecs.

pub fn strip_contents(self) -> Self

TODO: provide a better way to create an empty PreemptionRecord but with entries for a given set of tids.

pub fn split_map<F, R>(&mut self, splitter: F)

Iterates over each sched event and applies function event -> *event yielding resulting iterator as new events This effectively moves content of global allowing to split or delete events based on the function provided

pub fn schedevents_iter_mut(&mut self) -> IterMut<'_, SchedEvent> ⓘ

Iterate over the schedevents.

pub fn preemptions_only(&mut self)

Leave only the per-thread preemption records, not the global schedule.

pub fn clone_preemptions_only(&self) -> Self

Make a copy just of the preemptions (cheap) rather than the whole schedule trace (expensive)

pub fn schedevents(&self) -> &Vec<SchedEvent>

Read-only access to the raw event schedule.

pub fn contains_schedevents(&self) -> bool

Returns true if the schedule trace (SchedEvent) record is nonempty.

pub fn from_vecs(bt: &BTreeMap<DetTid, Vec<(LogicalTime, Priority)>>) -> Self

Convert from a flat vector representation (Time,Priority_AFTER_Time) into the internal representation. The very first timeslice should have a zero timestamp, but it is ignored if nonzero.

pub fn into_global(self) -> Vec<SchedEvent>

Extracts the inner global events.

pub fn write_to_disk(&self, path: &Path) -> Result<(), String>

Save to disk.

pub fn validate(&self) -> Result<(), String>

Perform internal invariant checks on the PreemptionRecord and return an error if it is not well formed.

pub fn normalize(&self) -> PreemptionRecord

Normalize priorities for readibility.

pub fn with_latest_preempt_removed(&self) -> PreemptionRecord

Remove whichever is the latest preemption across all thread histories. If there are no priority changes in any thread history, the entire last thread (highest thread number) is completely removed. Note this function assumes the last priority change in the list has the latest preempt time.