PreemptionWriter

Struct PreemptionWriter 

pub struct PreemptionWriter { /* private fields */ }
A writer for a stream of preemption events.

Implementations

Source

impl PreemptionWriter

pub fn new(path: Option<PathBuf>) -> Self

A new, empty record of preemptions, with an optional location on disk that it will be written to. If no path is supplied, the results will accumulate in memory only.

pub fn with_epoch(self, epoch: DateTime<Utc>) -> Self

Store the virtual-time epoch the recorded logical times are measured from, so a replay can start its clock at the same instant.

pub fn is_empty(&self) -> bool

Does the record have zero entries?

pub fn len(&self) -> usize

Total number of elements in the record, across all threads.

pub fn register_thread(&mut self, tid: DetTid, prio: Priority)

Register a thread with its default/final priority.

pub fn insert_reprioritization( &mut self, tid: DetTid, time: LogicalTime, rcbs: u64, prior_prio: Priority, next_prio: Priority, )

Insert a new preemption point for the given thread. It must monotonically increase in time.

For now it (redundantly) takes both the priority of the timeslice just finished, and the next one coming up. This serves as a sanity check.

pub fn insert_chaos_epoch( &mut self, tid: DetTid, transition: ChaosEpochTransition, )

Record a deterministic slowdown epoch transition for replay.

pub fn insert_schedevent(&mut self, ev: SchedEvent)

Add a SchedEvent to the global log of thread behavior.

pub fn set_current(&mut self, tid: DetTid, new_prio: Priority)

Set the priority of the current thread after a change.

pub fn into_string(self) -> String

Abort writing to disk and instead gather the output thusfar into a string.

pub fn flush(self) -> Result<(), String>

Finish any IO necessary to flush the record to disk. This will also happen automatically on drop.