pub struct ThreadHistory {
pub final_prio: Priority,
/* private fields */
}Expand description
The record of priorities and preemptions for a particular thread.
Fields
final_prio: PriorityThe priority of the last timeslice, after the last preemption. (This is also the initial priority if there are no preemptions.)
Implementations
Sourceimpl ThreadHistory
impl ThreadHistory
Sourcepub fn into_iter(self) -> ThreadHistoryIterator ⓘ
pub fn into_iter(self) -> ThreadHistoryIterator ⓘ
Turns the thread history into an iterator that produces a stream of preemption events.
Sourcepub fn as_vec(&self) -> Vec<(LogicalTime, Priority)>
pub fn as_vec(&self) -> Vec<(LogicalTime, Priority)>
Flatten the time series into a uniform representation.
This is a (Time, Priority_AFTER_Time) representation.
The very first timeslice will have a zero timestamp.
Sourcepub fn initial_priority(&self) -> Priority
pub fn initial_priority(&self) -> Priority
Return the priority of the initial timeslice after the thread starts running.