Namespace

Struct Namespace 

pub struct Namespace(/* private fields */);
A namespace that may be unshared with Command::unshare.

Implementations

Source

impl Namespace

pub const CGROUP: Namespace

Cgroup namespace.

pub const IPC: Namespace

IPC namespace.

pub const NETWORK: Namespace

Network namespace.

pub const MOUNT: Namespace

Mount namespace.

pub const PID: Namespace

PID namespace.

pub const USER: Namespace

User and group namespace.

pub const UTS: Namespace

UTS namespace.

Source

impl Namespace

pub const fn empty() -> Namespace

Get a flags value with all bits unset.

pub const fn all() -> Namespace

Get a flags value with all known bits set.

pub const fn bits(&self) -> i32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: i32) -> Option<Namespace>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: i32) -> Namespace

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: i32) -> Namespace

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Namespace>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Namespace) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: Namespace) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: Namespace)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: Namespace)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Namespace)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: Namespace, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Namespace) -> Namespace

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: Namespace) -> Namespace

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: Namespace) -> Namespace

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Namespace) -> Namespace

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> Namespace

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl Namespace

pub const fn iter(&self) -> Iter<Namespace> ⓘ

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<Namespace> ⓘ

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.