pub struct PreemptionRecord { /* private fields */ }Expand description
A record of all the preemptions and other scheduling events that occur during execution.
Implementations
Sourceimpl PreemptionRecord
impl PreemptionRecord
Sourcepub fn from_sched_events(events: Vec<SchedEvent>) -> Self
pub fn from_sched_events(events: Vec<SchedEvent>) -> Self
TODO: This is not ideal because PreemptionRecord shouldn’t be doing double duty as an eventlog.
Sourcepub fn epoch(&self) -> Option<DateTime<Utc>>
pub fn epoch(&self) -> Option<DateTime<Utc>>
The virtual-time epoch this record was produced under, if it was stored.
Sourcepub fn extract_all(&self) -> BTreeMap<DetTid, ThreadHistory>
pub fn extract_all(&self) -> BTreeMap<DetTid, ThreadHistory>
Make a copy of everything in the PreemptionRecord in a public format.
Sourcepub fn strip_contents(self) -> Self
pub fn strip_contents(self) -> Self
TODO: provide a better way to create an empty PreemptionRecord but with entries for a given set of tids.
Sourcepub fn split_map<F, R>(&mut self, splitter: F)
pub fn split_map<F, R>(&mut self, splitter: F)
Iterates over each sched event and applies function event -> *event yielding resulting iterator as new events This effectively moves content of global allowing to split or delete events based on the function provided
Sourcepub fn schedevents_iter_mut(&mut self) -> IterMut<'_, SchedEvent> ⓘ
pub fn schedevents_iter_mut(&mut self) -> IterMut<'_, SchedEvent> ⓘ
Iterate over the schedevents.
Sourcepub fn preemptions_only(&mut self)
pub fn preemptions_only(&mut self)
Leave only the per-thread preemption records, not the global schedule.
Sourcepub fn clone_preemptions_only(&self) -> Self
pub fn clone_preemptions_only(&self) -> Self
Make a copy just of the preemptions (cheap) rather than the whole schedule trace (expensive)
Sourcepub fn schedevents(&self) -> &Vec<SchedEvent>
pub fn schedevents(&self) -> &Vec<SchedEvent>
Read-only access to the raw event schedule.
Sourcepub fn contains_schedevents(&self) -> bool
pub fn contains_schedevents(&self) -> bool
Returns true if the schedule trace (SchedEvent) record is nonempty.
Sourcepub fn from_vecs(bt: &BTreeMap<DetTid, Vec<(LogicalTime, Priority)>>) -> Self
pub fn from_vecs(bt: &BTreeMap<DetTid, Vec<(LogicalTime, Priority)>>) -> Self
Convert from a flat vector representation (Time,Priority_AFTER_Time) into the internal representation. The very first timeslice should have a zero timestamp, but it is ignored if nonzero.
Sourcepub fn into_global(self) -> Vec<SchedEvent>
pub fn into_global(self) -> Vec<SchedEvent>
Extracts the inner global events.
Sourcepub fn validate(&self) -> Result<(), String>
pub fn validate(&self) -> Result<(), String>
Perform internal invariant checks on the PreemptionRecord and return an error if it is not well formed.
Sourcepub fn normalize(&self) -> PreemptionRecord
pub fn normalize(&self) -> PreemptionRecord
Normalize priorities for readibility.
Sourcepub fn with_latest_preempt_removed(&self) -> PreemptionRecord
pub fn with_latest_preempt_removed(&self) -> PreemptionRecord
Remove whichever is the latest preemption across all thread histories. If there are no priority changes in any thread history, the entire last thread (highest thread number) is completely removed. Note this function assumes the last priority change in the list has the latest preempt time.