pub struct Namespace(/* private fields */);Expand description
A namespace that may be unshared with Command::unshare.
Implementations
Sourceimpl Namespace
impl Namespace
Sourcepub const fn bits(&self) -> i32
pub const fn bits(&self) -> i32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: i32) -> Option<Namespace>
pub const fn from_bits(bits: i32) -> Option<Namespace>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: i32) -> Namespace
pub const fn from_bits_truncate(bits: i32) -> Namespace
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: i32) -> Namespace
pub const fn from_bits_retain(bits: i32) -> Namespace
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Namespace>
pub fn from_name(name: &str) -> Option<Namespace>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Namespace) -> bool
pub const fn intersects(&self, other: Namespace) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Namespace) -> bool
pub const fn contains(&self, other: Namespace) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Namespace)
pub fn remove(&mut self, other: Namespace)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Namespace)
pub fn toggle(&mut self, other: Namespace)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Namespace, value: bool)
pub fn set(&mut self, other: Namespace, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Namespace) -> Namespace
pub const fn intersection(self, other: Namespace) -> Namespace
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Namespace) -> Namespace
pub const fn union(self, other: Namespace) -> Namespace
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Namespace) -> Namespace
pub const fn difference(self, other: Namespace) -> Namespace
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Namespace) -> Namespace
pub const fn symmetric_difference(self, other: Namespace) -> Namespace
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Namespace
pub const fn complement(self) -> Namespace
The bitwise negation (!) of the bits in self, truncating the result.