Widely useful small utilities.
Structs
- Retrying
Stderr - A
Writefor the supervisor’s own diagnostics on fd 2 that survives a NONBLOCKING description.
Constants
- STDERR_
DIAGNOSTIC_ DEADLINE - Total wall-clock ALL diagnostic writes in ONE PROCESS may spend waiting for a reader that is not draining. Hermit forks, so read the fork note below before treating this as the whole exit path’s budget.
Functions
- init_
shared_ stderr_ deadline_ origin - Create the origin cell every hermit process of this invocation shares.
- punch_
out_ print - A simple debugging helper function that makes it easy to printf-debug through layers of stdout/stderr caputure, such as when running under buck test/tpx.
- rcbs_
to_ duration - A helper function to convert a number of Retired Conditional Branches (RCBS) into
a
std::time::Durationvia theNANOS_PER_RCBdefined intypes.rs. - truncated
- A little better than the builtin string truncation in format strings, because it includes ellipses.